=========
Changelog
=========

Version 1.0.0
=============
- completely new package and module structure
- implementation of I/O classes for single files
- implementation of raster data classes for multiple files
- support for GeoTIFF and NetCDF data

Version 0.1.1
=============
- WARNING: this is an experimental release
- Refactored IO classes
- New modules are only available as commented code chunks

Version 0.1.0
=============
- TU Wiens internal package `pyraster` was recreated as `veranda`
- Support for GeoTIFF and NetCDF reading and writing
- Added auto-decoding for both GeoTIFF and NetCDF
